==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/RegistrationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder
import com.pulumi.azurenative.desktopvirtualization.kotlin.enums.RegistrationTokenOperation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a RegistrationInfo definition.
 * @property expirationTime Expiration time of registration token.
 * @property registrationTokenOperation The type of resetting the token.
 * @property token The registration token base64 encoded string.
 */
public data class RegistrationInfoArgs(
    public val expirationTime: Output<String>? = null,
    public val registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null,
    public val token: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder()
            .expirationTime(expirationTime?.applyValue({ args0 -> args0 }))
            .registrationTokenOperation(
                registrationTokenOperation?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .token(token?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RegistrationInfoArgs].
 */
@PulumiTagMarker
public class RegistrationInfoArgsBuilder internal constructor() {
    private var expirationTime: Output<String>? = null

    private var registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null

    private var token: Output<String>? = null

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("rkqesbirgawgayvw")
    public suspend fun expirationTime(`value`: Output<String>) {
        this.expirationTime = value
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("fegnukyrhviqbgct")
    public suspend
    fun registrationTokenOperation(`value`: Output<Either<String, RegistrationTokenOperation>>) {
        this.registrationTokenOperation = value
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("ppskfaesjutgmvvr")
    public suspend fun token(`value`: Output<String>) {
        this.token = value
    }

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("irtgdcygstfatywc")
    public suspend fun expirationTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expirationTime = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("tuwipqhmdblxephd")
    public suspend
    fun registrationTokenOperation(`value`: Either<String, RegistrationTokenOperation>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("amusbumalgqnsahp")
    public fun registrationTokenOperation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("belnuebsqhiskhrm")
    public fun registrationTokenOperation(`value`: RegistrationTokenOperation) {
        val toBeMapped = Either.ofRight<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("pknqriqcepppueka")
    public suspend fun token(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.token = mapped
    }

    internal fun build(): RegistrationInfoArgs = RegistrationInfoArgs(
        expirationTime = expirationTime,
        registrationTokenOperation = registrationTokenOperation,
        token = token,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/RegistrationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder
import com.pulumi.azurenative.desktopvirtualization.kotlin.enums.RegistrationTokenOperation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a RegistrationInfo definition.
 * @property expirationTime Expiration time of registration token.
 * @property registrationTokenOperation The type of resetting the token.
 * @property token The registration token base64 encoded string.
 */
public data class RegistrationInfoArgs(
    public val expirationTime: Output<String>? = null,
    public val registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null,
    public val token: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder()
            .expirationTime(expirationTime?.applyValue({ args0 -> args0 }))
            .registrationTokenOperation(
                registrationTokenOperation?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .token(token?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RegistrationInfoArgs].
 */
@PulumiTagMarker
public class RegistrationInfoArgsBuilder internal constructor() {
    private var expirationTime: Output<String>? = null

    private var registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null

    private var token: Output<String>? = null

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("avwvcwdghgmnomlk")
    public suspend fun expirationTime(`value`: Output<String>) {
        this.expirationTime = value
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("yjtgmnijanfttter")
    public suspend
    fun registrationTokenOperation(`value`: Output<Either<String, RegistrationTokenOperation>>) {
        this.registrationTokenOperation = value
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("jtouonnhlsgymdss")
    public suspend fun token(`value`: Output<String>) {
        this.token = value
    }

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("fqieqtsnaakodtja")
    public suspend fun expirationTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expirationTime = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("xkmtpbnorgwtxbbo")
    public suspend
    fun registrationTokenOperation(`value`: Either<String, RegistrationTokenOperation>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("tmenbvfpngrtxwbw")
    public fun registrationTokenOperation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("hbssgfernsneqgci")
    public fun registrationTokenOperation(`value`: RegistrationTokenOperation) {
        val toBeMapped = Either.ofRight<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("gqlfgsyhbekabeoi")
    public suspend fun token(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.token = mapped
    }

    internal fun build(): RegistrationInfoArgs = RegistrationInfoArgs(
        expirationTime = expirationTime,
        registrationTokenOperation = registrationTokenOperation,
        token = token,
    )
}
